@@ -132,10 +132,6 @@ as.phylo.transmat <- function(x,
   Nnode <- length(phyloNodes)
   # create labels for each phylo node based on infector id
   phylo.label <- tm$inf
-  # this is an alternate label form like i_j
-  #phylo.label <- sapply(1:length(phyloNodes),function(r) {
-  #  paste(tm[r,"inf"],tm[r,"sus"],sep="_")
-  #})
 
   # set default durations
   # since we don't know how long the graph vertices live, assume entire duration
@@ -234,7 +230,6 @@ as.network.transmat <- function(x, ...) {
   network.vertex.names(net) <- ids
 
   # add the other attributes to edges and vertices
-  #net%e%"at"<-tm$at
   set.edge.attribute(net, "at", tm$at)
   set.edge.attribute(net, "infDur", tm$infDur)
   set.edge.attribute(net, "transProb", tm$transProb)
@@ -251,17 +246,14 @@ as.network.transmat <- function(x, ...) {
 #'
 #' @description Plots the infection tree described in a \code{\link{transmat}}
 #'              object in one of several styles: phylogenetic tree, an un-rooted
-#'              network, a hierarchical tree, or a transmissionTimeline.
+#'              network or a hierarchical tree.
 #'
 #' @param x A \code{\link{transmat}} object to be plotted
-#' @param style Character name of plot style. One of "phylo", "network",
-#'        or "transmissionTimeline"
+#' @param style Character name of plot style. One of "phylo" or "network".
 #' @param ...  Additional plot arguments to be passed to lower-level plot
 #'        functions (plot.network, plot.phylo, etc)
 #'
-#' @details The phylo plot requires the \code{ape} package. The
-#' \code{ndtv::transmissionTimeline} requires that the \code{ndtv} package
-#' is installed. All of the options are essentially
+#' @details The phylo plot requires the \code{ape} package. The options are
 #' wrappers to other plot calls with some appropriate preset arguments.
 #'
 #' @export
@@ -270,15 +262,13 @@ as.network.transmat <- function(x, ...) {
 #' @seealso \code{\link{plot.network}},\code{\link[ape]{plot.phylo}}
 #'
 plot.transmat <- function(x,
-                          style=c("phylo", "network", "transmissionTimeline"),
+                          style = c("phylo", "network"),
                           ...) {
 
   style <- match.arg(style)
 
   switch(style,
-    "transmissionTimeline" = tm_transsmissionTree_plot(x, ...),
     "network" = plot.network(as.network(x), ...),
-    # "gv_tree" = tm_gv_tree_plot(x, ...),
     "phylo" = plot(as.phylo.transmat(x),
                    show.node.label = TRUE,
                    root.edge = TRUE,
@@ -289,25 +279,6 @@ plot.transmat <- function(x,
 
 }
 
-
-# this is a wrapper that uses ndtv and graphviz to make a tree plot
-tm_gv_tree_plot <- function(tm, ...) {
-
-  # assumes graphviz is installed
-  net <- as.network(tm)
-
-  # calculate coords for transmission tree
-  treeCoords <- ndtv::network.layout.animate.Graphviz(net,
-                                              layout.par =
-                                                list(gv.engine = "dot",
-                                                     gv.args = "-Granksep=2"))
-  treeCoords <- ndtv::layout.normalize(treeCoords, keep.aspect.ratio = FALSE)
-
-  # peek at it
-  plot(net, coord = treeCoords, displaylabels = TRUE, jitter = FALSE,
-       label.pos = 2, label.cex = 0.7, ...)
-}
-
 #' @export
 #' @aliases transmat
 #' @rdname get_transmat
@@ -318,9 +289,3 @@ is.transmat <- function(x) {
     return(FALSE)
   }
 }
-
-# this is a wrapper to load the namespace and call the transmissionTimeline
-tm_transsmissionTree_plot <- function(x, ...) {
-  requireNamespace("ndtv")
-  ndtv::transmissionTimeline(x, ...)
-}
\ No newline at end of file
