@@ -166,8 +166,8 @@
 #' # Printing the sim object shows the randomly drawn values for each simulation
 #' sim
 #'
-#' # These are available to access here
-#' sim$param$random.params.values
+#' # Parameter sets can be extracted with:
+#' get_param_set(sim)
 #'
 param.net <- function(inf.prob, inter.eff, inter.start, act.rate, rec.rate,
                       a.rate, ds.rate, di.rate, dr.rate, inf.prob.g2,
@@ -186,7 +186,7 @@ param.net <- function(inf.prob, inter.eff, inter.start, act.rate, rec.rate,
   dot.args <- list(...)
   names.dot.args <- names(dot.args)
   if (length(dot.args) > 0) {
-    for (i in 1:length(dot.args)) {
+    for (i in seq_along(dot.args)) {
       p[[names.dot.args[i]]] <- dot.args[[i]]
     }
   }
@@ -607,7 +607,7 @@ init.net <- function(i.num, r.num, i.num.g2, r.num.g2,
   dot.args <- list(...)
   names.dot.args <- names(dot.args)
   if (length(dot.args) > 0) {
-    for (i in 1:length(dot.args)) {
+    for (i in seq_along(dot.args)) {
       p[[names.dot.args[i]]] <- dot.args[[i]]
     }
   }
@@ -665,6 +665,12 @@ init.net <- function(i.num, r.num, i.num.g2, r.num.g2,
 #' @param tergmLite Logical indicating usage of either \code{tergm}
 #'        (\code{tergmLite = FALSE}), or \code{tergmLite}
 #'        (\code{tergmLite = TRUE}). Default of \code{FALSE}.
+#' @param cumulative.edgelist If \code{TRUE}, calculates a cumulative edgelist
+#'        within the network simulation module. This is used when tergmLite is
+#'        used and the entire networkDynamic object is not used.
+#' @param truncate.el.cuml Number of time steps of the cumulative edgelist to
+#'        retain. See help file for \code{\link{update_cumulative_edgelist}} for
+#'        options.
 #' @param attr.rules A list containing the  rules for setting the attributes of
 #'        incoming nodes, with one list element per attribute to be set (see
 #'        details below).
@@ -798,6 +804,8 @@ control.net <- function(type,
                         ncores = 1,
                         resimulate.network = FALSE,
                         tergmLite = FALSE,
+                        cumulative.edgelist = FALSE,
+                        truncate.el.cuml = 0,
                         attr.rules,
                         epi.by,
                         initialize.FUN = initialize.net,
@@ -837,7 +845,7 @@ control.net <- function(type,
   dot.args <- list(...)
   names.dot.args <- names(dot.args)
   if (length(dot.args) > 0) {
-    for (i in 1:length(dot.args)) {
+    for (i in seq_along(dot.args)) {
       p[[names.dot.args[i]]] <- dot.args[[i]]
     }
   }
@@ -868,7 +876,7 @@ control.net <- function(type,
   bi.nms <- bi.mods
   index <- 1
   if (is.null(p[["type"]])) {
-    for (i in 1:length(bi.mods)) {
+    for (i in seq_along(bi.mods)) {
       if (!is.null(p[[bi.mods[i]]])) {
         p[["bi.mods"]][index] <- bi.mods[i]
         index <- index + 1
@@ -889,7 +897,7 @@ control.net <- function(type,
                                         "prevalence.FUN"))]
   if (length(bi.nms) > 0) {
     flag1 <- logical()
-    for (args in 1:length(bi.nms)) {
+    for (args in seq_along(bi.nms)) {
       if (!(is.null(p[[bi.nms[args]]]))) {
         temp1 <- get(gsub(".FUN", ".net", bi.nms[args]))
         temp2 <- p[[bi.nms[args]]]
@@ -909,8 +917,7 @@ control.net <- function(type,
   }
 
   if (is.null(p[["nsteps"]])) {
-    stop("Specify nsteps",
-         call. = FALSE)
+    stop("Specify nsteps", call. = FALSE)
   }
 
   if (missing(attr.rules)) {
