@@ -18,13 +18,15 @@
 #' @keywords netUtils internal
 #'
 prevalence.net <- function(dat, at) {
-
   active <- get_attr(dat, "active")
-  type <- get_control(dat, "type")
+
+  type <- get_control(dat, "type", override.null.error = TRUE)
+  type <- if (is.null(type)) "None" else type
+
   groups <- get_param(dat, "groups")
 
   # Subset attr to active == 1
-  l <- lapply(1:length(dat$attr), function(x) dat$attr[[x]][active == 1])
+  l <- lapply(seq_along(dat$attr), function(x) dat$attr[[x]][active == 1])
   names(l) <- names(dat$attr)
   l$active <- l$infTime <- NULL
 
@@ -44,40 +46,37 @@ prevalence.net <- function(dat, at) {
   }
 
   if (groups == 1) {
-
     dat <- set_epi(dat, "s.num", at, sum(status == "s"))
     if (eb == TRUE) {
-      for (i in 1:length(ebun)) {
+      for (i in seq_along(ebun)) {
         ebn.temp <- paste0("s.num", ebun[i])
         dat <- set_epi(dat, ebn.temp, at, sum(status == "s" &
-                                                get(ebn) == ebv[i]))
+          get(ebn) == ebv[i]))
       }
     }
 
     dat <- set_epi(dat, "i.num", at, sum(status == "i"))
     if (eb == TRUE) {
-      for (i in 1:length(ebun)) {
+      for (i in seq_along(ebun)) {
         ebn.temp <- paste0("i.num", ebun[i])
         dat <- set_epi(dat, ebn.temp, at, sum(status == "i" &
-                                                get(ebn) == ebv[i]))
+          get(ebn) == ebv[i]))
       }
     }
 
-    if (!is.null(type)) {
-      if (type == "SIR") {
-        dat <- set_epi(dat, "r.num", at, sum(status == "r"))
-        if (eb == TRUE) {
-          for (i in 1:length(ebun)) {
-            ebn.temp <- paste0("r.num", ebun[i])
-            dat <- set_epi(dat, ebn.temp, at, sum(status == "r" &
-                                                    get(ebn) == ebv[i]))
-          }
+    if (type == "SIR") {
+      dat <- set_epi(dat, "r.num", at, sum(status == "r"))
+      if (eb == TRUE) {
+        for (i in seq_along(ebun)) {
+          ebn.temp <- paste0("r.num", ebun[i])
+          dat <- set_epi(dat, ebn.temp, at, sum(status == "r" &
+            get(ebn) == ebv[i]))
         }
       }
     }
     dat <- set_epi(dat, "num", at, length(status))
     if (eb == TRUE) {
-      for (i in 1:length(ebun)) {
+      for (i in seq_along(ebun)) {
         ebn.temp <- paste0("num", ebun[i])
         dat <- set_epi(dat, ebn.temp, at, sum(get(ebn) == ebv[i]))
       }
@@ -90,81 +89,77 @@ prevalence.net <- function(dat, at) {
 
     dat <- set_epi(dat, "s.num", at, sum(status == "s" & group == 1))
     if (eb == TRUE) {
-      for (i in 1:length(ebun)) {
+      for (i in seq_along(ebun)) {
         ebn.temp <- paste0("s.num", ebun[i])
         dat <- set_epi(dat, ebn.temp, at, sum(status == "s" &
-                                                group == 1 &
-                                                get(ebn) == ebv[i]))
+          group == 1 &
+          get(ebn) == ebv[i]))
       }
     }
     dat <- set_epi(dat, "i.num", at, sum(status == "i" & group == 1))
     if (eb == TRUE) {
-      for (i in 1:length(ebun)) {
+      for (i in seq_along(ebun)) {
         ebn.temp <- paste0("i.num", ebun[i])
         dat <- set_epi(dat, ebn.temp, at, sum(status == "i" &
-                                                group == 1 &
-                                                get(ebn) == ebv[i]))
+          group == 1 &
+          get(ebn) == ebv[i]))
       }
     }
-    if (!is.null(type)) {
-      if (type == "SIR") {
-        dat <- set_epi(dat, "r.num", at, sum(status == "r" & group == 1))
-        if (eb == TRUE) {
-          for (i in 1:length(ebun)) {
-            ebn.temp <- paste0("r.num", ebun[i])
-            dat <- set_epi(dat, ebn.temp, at, sum(status == "r" &
-                                                    group == 1 &
-                                                    get(ebn) == ebv[i]))
-          }
+    if (type == "SIR") {
+      dat <- set_epi(dat, "r.num", at, sum(status == "r" & group == 1))
+      if (eb == TRUE) {
+        for (i in seq_along(ebun)) {
+          ebn.temp <- paste0("r.num", ebun[i])
+          dat <- set_epi(dat, ebn.temp, at, sum(status == "r" &
+            group == 1 &
+            get(ebn) == ebv[i]))
         }
       }
     }
     dat <- set_epi(dat, "num", at, sum(group == 1))
     dat$epi$num[at] <- sum(group == 1)
     if (eb == TRUE) {
-      for (i in 1:length(ebun)) {
+      for (i in seq_along(ebun)) {
         ebn.temp <- paste0("num", ebun[i])
         dat <- set_epi(dat, ebn.temp, at, sum(group == 1 &
-                                                get(ebn) == ebv[i]))
+          get(ebn) == ebv[i]))
       }
     }
     dat <- set_epi(dat, "s.num.g2", at, sum(status == "s" & group == 2))
     if (eb == TRUE) {
-      for (i in 1:length(ebun)) {
+      for (i in seq_along(ebun)) {
         ebn.temp <- paste0("s.num.g2", ebun[i])
         dat <- set_epi(dat, ebn.temp, at, sum(status == "s" &
-                                                group == 2 &
-                                                get(ebn) == ebv[i]))
+          group == 2 &
+          get(ebn) == ebv[i]))
       }
     }
     dat <- set_epi(dat, "i.num.g2", at, sum(status == "i" & group == 2))
     if (eb == TRUE) {
-      for (i in 1:length(ebun)) {
+      for (i in seq_along(ebun)) {
         ebn.temp <- paste0("i.num.g2", ebun[i])
         dat <- set_epi(dat, ebn.temp, at, sum(status == "i" &
-                                                group == 2 &
-                                                get(ebn) == ebv[i]))
+          group == 2 &
+          get(ebn) == ebv[i]))
       }
     }
-    if (!is.null(type)) {
-      if (type == "SIR") {
-        dat <- set_epi(dat, "r.num.g2", at, sum(status == "r" & group == 2))
-        if (eb == TRUE) {
-          for (i in 1:length(ebun)) {
-            ebn.temp <- paste0("r.num.g2", ebun[i])
-            dat <- set_epi(dat, ebn.temp, at, sum(status == "r" &
-                                                    group == 2 &
-                                                    get(ebn) == ebv[i]))
-          }
+    if (type == "SIR") {
+      dat <- set_epi(dat, "r.num.g2", at, sum(status == "r" & group == 2))
+      if (eb == TRUE) {
+        for (i in seq_along(ebun)) {
+          ebn.temp <- paste0("r.num.g2", ebun[i])
+          dat <- set_epi(dat, ebn.temp, at, sum(status == "r" &
+            group == 2 &
+            get(ebn) == ebv[i]))
         }
       }
     }
     dat <- set_epi(dat, "num.g2", at, sum(group == 2))
     if (eb == TRUE) {
-      for (i in 1:length(ebun)) {
+      for (i in seq_along(ebun)) {
         ebn.temp <- paste0("num.g2", ebun[i])
         dat <- set_epi(dat, ebn.temp, at, sum(group == 2 &
-                                                get(ebn) == ebv[i]))
+          get(ebn) == ebv[i]))
       }
     }
   }
